# -*- coding: utf-8 -*-
"""
@uthor: F Unseld

This is the cleaned up version of the script used to generate Fig 2 and S2 in 
the paper "On-chip Integration of Si/SiGe-based Quantum Dots and Switched-
capacitor Circuits". 
"""

import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from matplotlib.ticker import EngFormatter
import os

#%%

DataDevA = pd.read_csv('../Fig2/DevA.csv')
DataDevA = DataDevA.set_index(DataDevA.columns[0])
DataDevB = pd.read_csv('../Fig2/DevB.csv')
DataDevB = DataDevB.set_index(DataDevB.columns[0])
DataDevC = pd.read_csv('../Fig2/DevC.csv')
DataDevC = DataDevC.set_index(DataDevC.columns[0])

#For legacy reasons
static_Vin_A = np.array(DataDevA.dropna(axis = 'rows', subset = [DataDevA.columns[0]]).index)
static_ID_A = np.array(DataDevA.dropna(axis = 'rows', subset = [DataDevA.columns[0]])['static'])
floating_Vin_A = np.array(DataDevA.dropna(axis = 'rows', subset = [DataDevA.columns[1]]).index)
floating_ID_A = np.array(DataDevA.dropna(axis = 'rows', subset = [DataDevA.columns[1]])['floating'])

static_Vin_B = np.array(DataDevB.dropna(axis = 'rows', subset = [DataDevB.columns[0]]).index)
static_ID_B = np.array(DataDevB.dropna(axis = 'rows', subset = [DataDevB.columns[0]])['static'])
floating_Vin_B = np.array(DataDevB.dropna(axis = 'rows', subset = [DataDevB.columns[1]]).index)
floating_ID_B = np.array(DataDevB.dropna(axis = 'rows', subset = [DataDevB.columns[1]])['floating'])

static_Vin_C = np.array(DataDevC.dropna(axis = 'rows', subset = [DataDevC.columns[0]]).index)
static_ID_C = np.array(DataDevC.dropna(axis = 'rows', subset = [DataDevC.columns[0]])['static'])
floating_Vin_C = np.array(DataDevC.dropna(axis = 'rows', subset = [DataDevC.columns[1]]).index)
floating_ID_C = np.array(DataDevC.dropna(axis = 'rows', subset = [DataDevC.columns[1]])['floating'])

#%%

fig,axs = plt.subplots(nrows = 1, ncols = 2, dpi = 450, figsize=(5.4,3),sharey=True)
fig.subplots_adjust(wspace =0,left =0)

linewidth = 0.7
elinewidth = 0.5
glinewidth = 0.20

marker = 'x'
markersize = 2
colrs = ['C1','C0','C2']

axs[0].plot(static_Vin_B, static_ID_B,'C0', linewidth = linewidth)
axs[0].plot(floating_Vin_B, floating_ID_B,'C1', linewidth = linewidth)
axs[0].legend(['Static','Floating'], title="Device B",)
axs[0].set_xlim((1.195,1.251))

axs[1].plot(static_Vin_C, static_ID_C,'C0', linewidth = linewidth)
axs[1].plot(floating_Vin_C, floating_ID_C,'C1', linewidth = linewidth)
axs[1].legend(['Static','Floating'], title="Device C",)
axs[1].set_xlim((1.415,1.525))


for ax in axs:
    ax.minorticks_on()
    ax.grid(which='major', linestyle='--', lw = glinewidth)
    ax.grid(which='minor', linestyle=':', lw = glinewidth)


    axs[0].set_ylabel(r'$\mathregular{I_d}$ (nA)')
    ax.set_xlabel(r'$\mathregular{V_{in}} (V)$')

    ax.xaxis.label.set_size(12)
    ax.yaxis.label.set_size(12)
    ax.xaxis.set_tick_params(labelsize=12)
    ax.yaxis.set_tick_params(labelsize=12)

# plt.yticks(fontname = "Calibri")
# plt.xticks(fontname = "Calibri")

axs[0].set_xticks(np.arange(1.2,1.251,0.025))
axs[1].set_xticks(np.arange(1.42,1.52,0.05))
axs[0].set_yticks(np.arange(0,1.1,0.5))

fig.tight_layout()
plt.savefig('../Fig2/Fig2.png',bbox_inches = 'tight')
plt.savefig('../Fig2/Fig2.pdf',bbox_inches = 'tight')

#%%
fig,ax = plt.subplots(nrows = 1, ncols = 1, dpi = 450, figsize=(5.4/2,3),sharey=True)


linewidth = 0.7
elinewidth = 0.5
glinewidth = 0.20

marker = 'x'
markersize = 2
colrs = ['C1','C0','C2']

ax.plot(static_Vin_A, static_ID_A,'C0', linewidth = linewidth)
ax.plot(floating_Vin_A, floating_ID_A,'C1', linewidth = linewidth)
ax.legend(['Static','Floating'], title="Device A",)
ax.set_xlim((1.05,1.355))
ax.set_ylim((-10e-3,125e-3))

ax.minorticks_on()
ax.grid(which='major', linestyle='--', lw = glinewidth)
ax.grid(which='minor', linestyle=':', lw = glinewidth)



ax.set_ylabel(r'$\mathregular{I_d}$ (nA)')
ax.set_xlabel(r'$\mathregular{V_{in}} (V)$')


ax.xaxis.label.set_size(12)
ax.yaxis.label.set_size(12)
ax.xaxis.set_tick_params(labelsize=12)
ax.yaxis.set_tick_params(labelsize=12)

ax.set_xticks(np.arange(1.1,1.351,0.125))
ax.set_yticks(np.arange(0,121e-3,20e-3))

# fig.tight_layout()
plt.savefig('../Fig2/FigS2.png',bbox_inches = 'tight')
plt.savefig('../Fig2/FigS2.pdf',bbox_inches = 'tight')