# -*- coding: utf-8 -*-
"""
author: F Unseld
This is the cleand up version of the script used to generate Figure S3a and S3b. 
"""
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from matplotlib import cm
import os
#%% Figure S3a
RawData = pd.read_csv('../FigS3/VinVsdId.csv', header = [0,1], index_col=[0,1])
RawData.columns = RawData.columns.droplevel()
RawData.index = RawData.index.droplevel()

Vsd, Vin = np.meshgrid(np.array(RawData.index).astype(float), np.array(RawData.columns).astype(float)*1e-3)
Id = RawData.transpose().astype(float)

fig,ax = plt.subplots(dpi = 450, figsize=(6*.8,4*.8))


lvls = np.linspace(-2,2,25)

cf = ax.contourf(Vin,Vsd,np.clip(Id*1e9,min(lvls),max(lvls)),
                 levels = lvls,
                 cmap=plt.cm.bwr,
                ) #



ax.set_xlabel(r'$\mathregular{V_{g}\ (V)}$')
ax.set_ylabel('$\mathregular{V_{in}\ (mV)}$')

linewidth = 0.7
elinewidth = 0.5
glinewidth = 0.30
ax.minorticks_on()
ax.grid(which='major', linestyle='--', lw = glinewidth)
ax.grid(which='minor', linestyle=':', lw = glinewidth)


clb = fig.colorbar(cf, ax=ax,
                   ticks=np.round(np.arange(-2,2.01,.5),12),
                   )
clb.set_label(r'$\mathregular{I_{d}\ (nA)}$', rotation=90)

fig.tight_layout(h_pad=1, w_pad=1)
plt.savefig('../FigS3/FigS3a.png',bbox_inches = 'tight')
plt.savefig('../FigS3/FigS3a.pdf',bbox_inches = 'tight')

#%% Figure S3b
RawData = pd.read_csv('../FigS3/VgVinId.csv', header = [0,1], index_col=[0,1])
RawData.columns = RawData.columns.droplevel()
RawData.index = RawData.index.droplevel()

Vg, Vin = np.meshgrid(np.array(RawData.index).astype(float)*1e-3, np.array(RawData.columns).astype(float))
Id = RawData.transpose().astype(float)

fig,ax = plt.subplots(dpi = 450, figsize=(6*.8,4*.8))
lvls = np.linspace(-.025,.45,20)

cf = ax.contourf(Vg,Vin,np.array(Id)*1e9, levels = lvls,cmap=cm.CMRmap) #
ax.set_xlim((1.6,2.2))

ax.set_xlabel(r'$\mathregular{V_{g}\ (V)}$')
ax.set_ylabel('$\mathregular{V_{in}\ (V)}$')

ax.minorticks_on()
ax.grid(which='major', linestyle='--',linewidth=0.25)
ax.grid(which='minor', linestyle=':',linewidth=0.25)

clb = fig.colorbar(cf, ax=ax,)
clb.set_label(r'$\mathregular{I_{d}\ (nA)} $', rotation=90)

fig.tight_layout(h_pad=1, w_pad=1)
plt.savefig('../FigS3/FigS3b.png',bbox_inches = 'tight')
plt.savefig('../FigS3/FigS3b.pdf',bbox_inches = 'tight')